# Function 1 Round a stem. The stem is read from the CVT, rounded, and written back to the CVT. The function returns the CVT index of the next stem, so it can be called in a loop to round a number of stems. Arguments on stack: _cvt_stem_

Assembly |  | Stack
--- | --- | ---
PUSHW[ ] | 1 value pushed
1 | function index
FDEF[ ] | FunctionDefinition
DUP[ ] | DuplicateTopStack | cvt_stem cvt_stem
DUP[ ] | DuplicateTopStack | cvt_stem cvt_stem cvt_stem
RCVT[ ] | ReadCVT | cvt_stem cvt_stem stem
ROUND[01] | Round | cvt_stem cvt_stem round(stem)
WCVTP[ ] | WriteCVTInPixels | cvt_stem
PUSHB[ ] | 1 value pushed
1 | next CVT index | cvt_stem 1
ADD[ ] | Add | cvt_stem+1
ENDF[ ] | EndFunctionDefinition

Returns on stack: The CVT index of the last stem + 1 (next CVT stem index)